# -*- coding: utf-8 -*-
# Generated by Django 1.9.5 on 2016-06-07 21:42
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('countries', '0005_auto_20160607_1416'),
    ]

    operations = [
        migrations.AlterField(
            model_name='country',
            name='common_name',
            field=models.CharField(default='test', help_text=b'Common Country name', max_length=255, unique=True),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='country',
            name='name',
            field=models.CharField(blank=True, help_text=b'Official Country name (ISO Full name)', max_length=255, null=True),
        ),
    ]
